<?php

namespace Litepie\Blog\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Blog\Forms\BlogCategory as BlogCategoryForm;
use Litepie\Blog\Http\Requests\BlogCategoryResourceRequest;
use Litepie\Blog\Http\Resources\BlogCategoryResource;
use Litepie\Blog\Http\Resources\BlogCategoriesCollection;
use Litepie\Blog\Models\BlogCategory;
use Litepie\Blog\Actions\BlogCategoryAction;
use Litepie\Blog\Actions\BlogCategoryActions;


/**
 * Resource controller class for blog_category.
 */
class BlogCategoryResourceController extends BaseController
{

    /**
     * Initialize blog_category resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = BlogCategoryForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('litepie.blog.modules'), 'blog', guard_url('blog'));
            return $next($request);
        });
    }

    /**
     * Display a list of blog_category.
     *
     * @return Response
     */
    public function index(BlogCategoryResourceRequest $request)
    {
        $request = $request->all();
        $page = BlogCategoryActions::run('paginate', $request);

        $data = new BlogCategoriesCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('blog::blog_category.names'))
            ->view('blog::blog_category.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display blog_category.
     *
     * @param Request $request
     * @param Model   $blog_category
     *
     * @return Response
     */
    public function show(BlogCategoryResourceRequest $request, BlogCategory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new BlogCategoryResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('blog::blog_category.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('blog::blog_category.show')
            ->output();
    }

    /**
     * Show the form for creating a new blog_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BlogCategoryResourceRequest $request, BlogCategory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new BlogCategoryResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('blog::blog_category.name'))
            ->view('blog::blog_category.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new blog_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BlogCategoryResourceRequest $request, BlogCategory $model)
    {
        try {
            $request = $request->all();
            $model = BlogCategoryAction::run('store', $model, $request);
            $data = new BlogCategoryResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('blog::blog_category.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('blog/blog_category/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/blog/blog_category'))
                ->redirect();
        }

    }

    /**
     * Show blog_category for editing.
     *
     * @param Request $request
     * @param Model   $blog_category
     *
     * @return Response
     */
    public function edit(BlogCategoryResourceRequest $request, BlogCategory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new BlogCategoryResource($model);
        // return view('blog::blog_category.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('blog::blog_category.name'))
            ->view('blog::blog_category.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the blog_category.
     *
     * @param Request $request
     * @param Model   $blog_category
     *
     * @return Response
     */
    public function update(BlogCategoryResourceRequest $request, BlogCategory $model)
    {
        try {
            $request = $request->all();
            $model = BlogCategoryAction::run('update', $model, $request);
            $data = new BlogCategoryResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('blog::blog_category.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('blog/blog_category/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('blog/blog_category/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the blog_category.
     *
     * @param Model   $blog_category
     *
     * @return Response
     */
    public function destroy(BlogCategoryResourceRequest $request, BlogCategory $model)
    {
        try {

            $request = $request->all();
            $model = BlogCategoryAction::run('destroy', $model, $request);
            $data = new BlogCategoryResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('blog::blog_category.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('blog/blog_category/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('blog/blog_category/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
